/*
FUNCTION: divide

USAGE:
divide(numerator, denominator)

INPUT PARAMETERS:
numerator - 8-bit positive numerator
denominator - 8-bit positive denominator

RETURN VALUE:
8-bit positive fraction obtained by dividing the numerator by denominator

PURPOSE:
To implement the division operation by a series of shifts and subtracts

DESCRIPTION:
The division operation is implemented as a series of shifts and subtracts.
After every left shift, if the numerator is greater than the denominator,
then a bit in the quotient is set, starting at the most significant bit.
Division stops if the numerator equals the denominator or if the numerator
has been shifted left 8 times.

AUTHOR:
Amey Deosthali
Embedded Signal Processing Laboratory
The University of Texas at Austin
amey@vision.ece.utexas.edu

VERSION:
%W% %G%

COPYRIGHT:
Copyright (c) 1998-1999 The University of Texas
All rights reserved.
See the file COPYRIGHT for copyright notice, limitation
of liability, and disclaimer of warranty provisions.
*/

unsigned char divide (unsigned char numerator, unsigned char denominator)
{
        unsigned char mask = 0x80;              /* Mask used for division */
        unsigned char result = 0;               /* 8-bit positive result */

        if (numerator == denominator)           /* If numerator & denominator */
                return (0xFF);                  /* are equal, return 0xFFFF */

        /* Loop until numerator is not equal to denominator or */
        /* until the mask is greater than 0 (8 times) */
        while ((numerator != 0) && (mask > 0))
        {
                numerator = numerator << 1;     /* Multiply numerator by 2 */

                if (numerator >= denominator)
                {
                        result = result | mask; /* Set bit in quotient */
                        numerator = numerator - denominator;
                }

                mask = mask >> 1;               /* Shift mask right 1 bit */
        }

        return (result);                        /* Return positive fraction */
}
